"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _styles = require("@mui/material/styles");

// ----------------------------------------------------------------------
function createGradient(color1, color2) {
  return "linear-gradient(to bottom, ".concat(color1, ", ").concat(color2, ")");
} // Setup Colors


var PRIMARY = {
  // lighter: '#C8FACD',
  // light: '#5BE584',
  // main: '#00AB55',
  // dark: '#007B55',
  // darker: '#005249'
  lighter: "#FFE9C9",
  light: "#FFAC4A",
  main: "#FF7000",
  dark: "#E2703A",
  darker: "#E16428"
};
var SECONDARY = {
  lighter: "#D6E4FF",
  light: "#84A9FF",
  main: "#3366FF",
  dark: "#1939B7",
  darker: "#091A7A"
};
var INFO = {
  lighter: "#D0F2FF",
  light: "#74CAFF",
  main: "#1890FF",
  dark: "#0C53B7",
  darker: "#04297A"
};
var SUCCESS = {
  lighter: "#E9FCD4",
  light: "#AAF27F",
  main: "#54D62C",
  dark: "#229A16",
  darker: "#08660D"
};
var WARNING = {
  lighter: "#FFF7CD",
  light: "#FFE16A",
  main: "#FFC107",
  dark: "#B78103",
  darker: "#7A4F01"
};
var ERROR = {
  lighter: "#FFE7D9",
  light: "#FFA48D",
  main: "#FF4842",
  dark: "#B72136",
  darker: "#7A0C2E"
};
var GREY = {
  0: "#FFFFFF",
  100: "#F9FAFB",
  200: "#F4F6F8",
  300: "#DFE3E8",
  400: "#C4CDD5",
  500: "#919EAB",
  600: "#637381",
  700: "#454F5B",
  800: "#212B36",
  900: "#161C24",
  5008: (0, _styles.alpha)("#919EAB", 0.08),
  50012: (0, _styles.alpha)("#919EAB", 0.12),
  50016: (0, _styles.alpha)("#919EAB", 0.16),
  50024: (0, _styles.alpha)("#919EAB", 0.24),
  50032: (0, _styles.alpha)("#919EAB", 0.32),
  50048: (0, _styles.alpha)("#919EAB", 0.48),
  50056: (0, _styles.alpha)("#919EAB", 0.56),
  50080: (0, _styles.alpha)("#919EAB", 0.8)
};
var GRADIENTS = {
  primary: createGradient(PRIMARY.light, PRIMARY.main),
  info: createGradient(INFO.light, INFO.main),
  success: createGradient(SUCCESS.light, SUCCESS.main),
  warning: createGradient(WARNING.light, WARNING.main),
  error: createGradient(ERROR.light, ERROR.main)
};
var Palette = {
  // LIGHT
  light: {
    mode: "light",
    primary: {
      lighter: PRIMARY.lighter,
      light: PRIMARY.light,
      main: PRIMARY.main,
      dark: PRIMARY.dark,
      darker: PRIMARY.darker,
      contrastText: "#fff"
    },
    secondary: {
      lighter: SECONDARY.lighter,
      light: SECONDARY.light,
      main: SECONDARY.main,
      dark: SECONDARY.dark,
      darker: SECONDARY.darker,
      contrastText: "#fff"
    },
    info: {
      lighter: INFO.lighter,
      light: INFO.light,
      main: INFO.main,
      dark: INFO.dark,
      darker: INFO.darker,
      contrastText: "#fff"
    },
    success: {
      lighter: SUCCESS.lighter,
      light: SUCCESS.light,
      main: SUCCESS.main,
      dark: SUCCESS.dark,
      darker: SUCCESS.darker,
      contrastText: GREY[800]
    },
    warning: {
      lighter: WARNING.lighter,
      light: WARNING.light,
      main: WARNING.main,
      dark: WARNING.dark,
      darker: WARNING.darker,
      contrastText: GREY[800]
    },
    error: {
      lighter: ERROR.lighter,
      light: ERROR.light,
      main: ERROR.main,
      dark: ERROR.dark,
      darker: ERROR.darker,
      contrastText: "#fff"
    },
    grey: GREY,
    gradients: GRADIENTS,
    text: {
      primary: GREY[800],
      secondary: GREY[600],
      disabled: GREY[500]
    },
    divider: GREY[50024],
    background: {
      paper: "#fff",
      "default": "#fff",
      neutral: GREY[200]
    },
    action: {
      active: GREY[600],
      hover: GREY[5008],
      selected: GREY[50016],
      disabled: GREY[50080],
      disabledBackground: GREY[50024],
      focus: GREY[50024],
      hoverOpacity: 0.08,
      disabledOpacity: 0.48
    }
  },
  // DARK
  dark: {
    mode: "dark",
    primary: {
      lighter: PRIMARY.lighter,
      light: PRIMARY.light,
      main: PRIMARY.main,
      dark: PRIMARY.dark,
      darker: PRIMARY.darker,
      contrastText: "#fff"
    },
    secondary: {
      lighter: SECONDARY.lighter,
      light: SECONDARY.light,
      main: SECONDARY.main,
      dark: SECONDARY.dark,
      darker: SECONDARY.darker,
      contrastText: "#fff"
    },
    info: {
      lighter: INFO.lighter,
      light: INFO.light,
      main: INFO.main,
      dark: INFO.dark,
      darker: INFO.darker,
      contrastText: "#fff"
    },
    success: {
      lighter: SUCCESS.lighter,
      light: SUCCESS.light,
      main: SUCCESS.main,
      dark: SUCCESS.dark,
      darker: SUCCESS.darker,
      contrastText: GREY[800]
    },
    warning: {
      lighter: WARNING.lighter,
      light: WARNING.light,
      main: WARNING.main,
      dark: WARNING.dark,
      darker: WARNING.darker,
      contrastText: GREY[800]
    },
    error: {
      lighter: ERROR.lighter,
      light: ERROR.light,
      main: ERROR.main,
      dark: ERROR.dark,
      darker: ERROR.darker,
      contrastText: "#fff"
    },
    grey: GREY,
    gradients: GRADIENTS,
    text: {
      primary: "#fff",
      secondary: GREY[500],
      disabled: GREY[600]
    },
    divider: GREY[50024],
    background: {
      paper: GREY[800],
      "default": GREY[900],
      neutral: GREY[50016]
    },
    action: {
      active: GREY[500],
      hover: GREY[5008],
      selected: GREY[50016],
      disabled: GREY[50080],
      disabledBackground: GREY[50024],
      focus: GREY[50024],
      hoverOpacity: 0.08,
      disabledOpacity: 0.48
    }
  }
};
var _default = Palette;
exports["default"] = _default;